==> openjdk-src-11.0.1.u13-2-armv7h.pkg.tar.xz: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_mfe.java <==
/*
 * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_mfe extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "MUR", "Rs" },
            { "aed", "dirham Emira arab ini" },
            { "aoa", "kwanza angole" },
            { "aud", "dolar ostralien" },
            { "bhd", "dinar bahre\u00efn" },
            { "bif", "fran burunde" },
            { "bwp", "pula ya botswane" },
            { "cad", "dolar kanadien" },
            { "cdf", "fran kongole" },
            { "chf", "fran swis" },
            { "cny", "yuan renminbi sinwa" },
            { "cve", "eskudo kapverdien" },
            { "djf", "fran djiboutien" },
            { "dzd", "dinar alzerien" },
            { "egp", "liv ezipsien" },
            { "ern", "nafka erythreen" },
            { "etb", "birr etiopien" },
            { "eur", "euro" },
            { "gbp", "liv sterlin" },
            { "ghc", "sedi ganeen" },
            { "gmd", "dalasi gambien" },
            { "gns", "fran gineen" },
            { "inr", "roupi" },
            { "jpy", "yen zapone" },
            { "kes", "shiling kenyan" },
            { "kmf", "fran komorien" },
            { "lrd", "dolar liberien" },
            { "lsl", "loti lezoto" },
            { "lyd", "dinar libien" },
            { "mad", "dirham marokin" },
            { "mga", "fran malgas" },
            { "mro", "ouguiya moritanien (1973\u20132017)" },
            { "mru", "ouguiya moritanien" },
            { "mur", "roupi morisien" },
            { "mwk", "kwacha malawit" },
            { "mzm", "metikal mozanbikin" },
            { "nad", "dolar namibien" },
            { "ngn", "naira nizerian" },
            { "rwf", "fran rwande" },
            { "sar", "rial saoudien" },
            { "scr", "roupi seselwa" },
            { "sdg", "dinar soudane" },
            { "sdp", "liv soudane" },
            { "shp", "liv Sainte-H\u00e9l\u00e8ne" },
            { "sll", "leonn Sierra-Leone" },
            { "sos", "shilingi somalien" },
            { "std", "dobra santomeen (1977\u20132017)" },
            { "stn", "dobra santomeen" },
            { "szl", "lilangeni swazi" },
            { "tnd", "dinar tinizien" },
            { "tzs", "shiling tanzanien" },
            { "ugx", "shiling ougande" },
            { "usd", "dolar amerikin" },
            { "xaf", "fran CFA (BEAC)" },
            { "xof", "fran CFA (BCEAO)" },
            { "zar", "rand sid-afrikin" },
            { "zmk", "kwacha zanbien (1968\u20132012)" },
            { "zmw", "kwacha zanbien" },
            { "zwd", "dolar zimbawe" },
        };
        return data;
    }
}

==> openjdk-src-22.0.2.u9-1-armv7h.pkg.tar.xz: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_mfe.java <==
/*
 * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_mfe extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "MUR", "Rs" },
            { "aed", "dirham Emira arab ini" },
            { "aoa", "kwanza angole" },
            { "aud", "dolar ostralien" },
            { "bhd", "dinar bahre\u00efn" },
            { "bif", "fran burunde" },
            { "bwp", "pula ya botswane" },
            { "cad", "dolar kanadien" },
            { "cdf", "fran kongole" },
            { "chf", "fran swis" },
            { "cny", "yuan renminbi sinwa" },
            { "cve", "eskudo kapverdien" },
            { "djf", "fran djiboutien" },
            { "dzd", "dinar alzerien" },
            { "egp", "liv ezipsien" },
            { "ern", "nafka erythreen" },
            { "etb", "birr etiopien" },
            { "eur", "euro" },
            { "gbp", "liv sterlin" },
            { "ghc", "sedi ganeen" },
            { "gmd", "dalasi gambien" },
            { "gns", "fran gineen" },
            { "inr", "roupi" },
            { "jpy", "yen zapone" },
            { "kes", "shiling kenyan" },
            { "kmf", "fran komorien" },
            { "lrd", "dolar liberien" },
            { "lsl", "loti lezoto" },
            { "lyd", "dinar libien" },
            { "mad", "dirham marokin" },
            { "mga", "fran malgas" },
            { "mro", "ouguiya moritanien (1973\u20132017)" },
            { "mru", "ouguiya moritanien" },
            { "mur", "roupi morisien" },
            { "mwk", "kwacha malawit" },
            { "mzm", "metikal mozanbikin" },
            { "nad", "dolar namibien" },
            { "ngn", "naira nizerian" },
            { "rwf", "fran rwande" },
            { "sar", "rial saoudien" },
            { "scr", "roupi seselwa" },
            { "sdg", "dinar soudane" },
            { "sdp", "liv soudane" },
            { "shp", "liv Sainte-H\u00e9l\u00e8ne" },
            { "sle", "leonn Sierra-Leone" },
            { "sll", "leonn Sierra-Leone (1964\u20142022)" },
            { "sos", "shilingi somalien" },
            { "std", "dobra santomeen (1977\u20132017)" },
            { "stn", "dobra santomeen" },
            { "szl", "lilangeni swazi" },
            { "tnd", "dinar tinizien" },
            { "tzs", "shiling tanzanien" },
            { "ugx", "shiling ougande" },
            { "usd", "dolar amerikin" },
            { "xaf", "fran CFA (BEAC)" },
            { "xof", "fran CFA (BCEAO)" },
            { "zar", "rand sid-afrikin" },
            { "zmk", "kwacha zanbien (1968\u20132012)" },
            { "zmw", "kwacha zanbien" },
            { "zwd", "dolar zimbawe" },
        };
        return data;
    }
}
